@@ -16,7 +16,7 @@ pub fn generate_load_single_arg(
                 // deserialize as boxed slice, so we have an owned object that we can reference
                 let slice_elem = &slice_type.elem;
                 quote! {
-                    elrond_wasm::load_single_arg::<Self::ArgumentApi, Box<[#slice_elem]>>(self.argument_api(), #arg_index_expr, #arg_name_expr)
+                    elrond_wasm::load_single_arg::<Self::Api, Box<[#slice_elem]>>(self.raw_vm_api(), #arg_index_expr, #arg_name_expr)
                 }
             } else {
                 // deserialize as owned object, so we can then have a reference to it
@@ -26,20 +26,20 @@ pub fn generate_load_single_arg(
                         if *ident == "str" {
                             // TODO: generalize for all unsized types using Box
                             return quote! {
-                                elrond_wasm::load_single_arg::<Self::ArgumentApi, Box<str>>(self.argument_api(), #arg_index_expr, #arg_name_expr)
+                                elrond_wasm::load_single_arg::<Self::Api, Box<str>>(self.raw_vm_api(), #arg_index_expr, #arg_name_expr)
                             };
                         }
                     }
                 }
 
                 quote! {
-                    elrond_wasm::load_single_arg::<Self::ArgumentApi, #referenced_type>(self.argument_api(), #arg_index_expr, #arg_name_expr)
+                    elrond_wasm::load_single_arg::<Self::Api, #referenced_type>(self.raw_vm_api(), #arg_index_expr, #arg_name_expr)
                 }
             }
         },
         _ => {
             quote! {
-                elrond_wasm::load_single_arg::<Self::ArgumentApi, #arg_ty>(self.argument_api(), #arg_index_expr, #arg_name_expr)
+                elrond_wasm::load_single_arg::<Self::Api, #arg_ty>(self.raw_vm_api(), #arg_index_expr, #arg_name_expr)
             }
         },
     }
